==> atlassian-user-1.9.1-sources.jar: com/atlassian/user/impl/ReadOnlyGroupManager.java <==
package com.atlassian.user.impl;

import com.atlassian.user.EntityException;
import com.atlassian.user.Group;
import com.atlassian.user.GroupManager;
import com.atlassian.user.User;

public abstract class ReadOnlyGroupManager implements GroupManager
{
    public Group createGroup(String groupName) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void removeGroup(Group group) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void saveGroup(Group group) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void addMembership(Group group, User user) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void removeMembership(Group group, User user) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    /**
     * Used to detemine whether an entity can be added (eg, can call {@link com.atlassian.user.UserManager#createUser(String)}
     * or{@link com.atlassian.user.GroupManager#createGroup(String)}
     */
    public boolean isCreative()
    {
        return false;
    }

    public boolean isReadOnly(Group group)
    {
        return true;
    }

    public boolean supportsExternalMembership() throws EntityException
    {
        return false;
    }
}

==> atlassian-user-2.0-sources.jar: com/atlassian/user/impl/ReadOnlyGroupManager.java <==
package com.atlassian.user.impl;

import com.atlassian.user.EntityException;
import com.atlassian.user.Group;
import com.atlassian.user.GroupManager;
import com.atlassian.user.User;

import java.util.List;
import java.util.Collections;

public abstract class ReadOnlyGroupManager implements GroupManager
{
    public List /*<Group>*/ getWritableGroups()
    {
        return Collections.EMPTY_LIST;
    }

    public Group createGroup(String groupName) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void removeGroup(Group group) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void saveGroup(Group group) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void addMembership(Group group, User user) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    public void removeMembership(Group group, User user) throws EntityException
    {
        throw new UnsupportedOperationException("Cannot write to read-only GroupManager [" + getIdentifier().getKey() +"]");
    }

    /**
     * Used to detemine whether an entity can be added (eg, can call {@link com.atlassian.user.UserManager#createUser(String)}
     * or{@link com.atlassian.user.GroupManager#createGroup(String)}
     */
    public boolean isCreative()
    {
        return false;
    }

    public boolean isReadOnly(Group group)
    {
        return true;
    }

    public boolean supportsExternalMembership() throws EntityException
    {
        return false;
    }
}
